# OpenVINO Stable Diffusion tools

This repository contains the tools for the OpenVINO Stable Diffusion project.

Refer to the [Text-to-Image Generation with Stable Diffusion and OpenVINO™](https://docs.openvino.ai/2022.3/notebooks/225-stable-diffusion-text-to-image-with-output.html) for more information.
